==> img0ch-2.1.21.tar.bz2: img0ch/_template/zeromin2/vthread_load_access.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/vthread_side_menu.cs" ?>

<div id="main">

<form id="vthreadAccessContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:Subject ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=load_access&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">仮想スレッド内のアクセス制限</a>
</div>

<h1>仮想スレッド内のアクセス制限</h1>

<?cs if:Code0 ?>
<?cs if:Done_vthread_save_access ?><div class="noticeSuccess" id="notify"><p>アクセス制限情報を更新しました</p></div>
<?cs else ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
現在仮想スレッド内において規制中のホストを一覧で表示しています。<br>
正規表現を用いてリモートホストの形式で記述する必要があります。
</p>

<div>
<textarea name="deny" cols="60" rows="10"><TMPL_VAR NAME=DeniedHosts></textarea><br />
<input type="submit" name="submit" value="更新" />
</div>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="vthread" />
<input type="hidden" name="method" value="save_access" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>" />
<input type="hidden" name="OK" value="load_access" />
<input type="hidden" name="NG" value="load_access" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.0.0.tar.bz2: img0ch/_template/zeromin2/vthread_load_access.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/vthread_side_menu.cs" ?>

<div id="main">

<form id="vthreadAccessContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:Subject ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=vthread&amp;method=load_access&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">仮想スレッド内のアクセス制限</a>
</div>

<h1>仮想スレッド内のアクセス制限</h1>

<?cs if:Code0 ?>
<?cs if:Done_vthread_save_access ?><div class="noticeSuccess" id="notify"><p>アクセス制限情報を更新しました</p></div>
<?cs else ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
現在仮想スレッド内において規制中のホストを一覧で表示しています。<br>
正規表現を用いてリモートホストの形式で記述する必要があります。
</p>

<div>
<textarea name="deny" cols="60" rows="10"><?cs var:html_escape(DeniedHosts) ?></textarea><br />
<input type="submit" name="submit" value="更新" />
</div>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="vthread" />
<input type="hidden" name="method" value="save_access" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>" />
<input type="hidden" name="OK" value="load_access" />
<input type="hidden" name="NG" value="load_access" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
